# chat/views.py
from django import forms
from django.http import HttpResponseRedirect
from django.shortcuts import render, reverse

def index(request):

    form = IndexForm(request.POST or None, initial={'room': 'pycun'})

    if request.POST:
        if form.is_valid():
            username = form.cleaned_data['username']
            room = form.cleaned_data['room']
            return HttpResponseRedirect(F"{reverse('room', args=[room])}?username={username}")

    return render(request, 'chat/index.html', {
        'form': form,
    })


class IndexForm(forms.Form):

    username = forms.CharField(label='Usuario', max_length=50)
    room = forms.CharField(label='Sala', max_length=50)


def room(request, room_name):

    url_websocket = F"ws://{request.headers.get('Host')}/ws/chat/{room_name}/"

    username = request.GET['username']

    return render(request, 'chat/room.html', {
        'room_name': room_name,
        'username': username,
        'url_websocket': url_websocket,
    })



# chat/consumers.py
import json
from asgiref.sync import async_to_sync
from channels.generic.websocket import WebsocketConsumer

class ChatConsumer(WebsocketConsumer):
    def connect(self):
        self.room_name = self.scope['url_route']['kwargs']['room_name']
        self.room_group_name = 'chat_%s' % self.room_name

        # Join room group
        async_to_sync(self.channel_layer.group_add)(
            self.room_group_name,
            self.channel_name
        )

        self.accept()

    def disconnect(self, close_code):
        # Leave room group
        async_to_sync(self.channel_layer.group_discard)(
            self.room_group_name,
            self.channel_name
        )

    # Receive message from WebSocket
    def receive(self, text_data):
        text_data_json = json.loads(text_data)
        message = text_data_json['message']

        # Send message to room group
        async_to_sync(self.channel_layer.group_send)(
            self.room_group_name,
            {
                'type': 'chat_message',
                'message': message
            }
        )

    # Receive message from room group
    def chat_message(self, event):
        message = event['message']

        # Send message to WebSocket
        self.send(text_data=json.dumps({
            'message': message
        }))